pub struct CommandId(pub u32);Expand description
An identifier for a command originating in the platform.
This is typically associated with items in the main menu, context menus, or buttons on modal dialogs.
Tuple Fields
0: u32Trait Implementations
impl Copy for CommandId
impl Eq for CommandId
impl StructuralPartialEq for CommandId