pub struct WgpuCtx<'a> {
pub device: &'a Device,
pub queue: &'a Queue,
pub target: &'a TextureView,
pub target_format: TextureFormat,
pub encoder: &'a mut CommandEncoder,
}Expand description
A collection of the types needed to render with wgpu.
This is provided to the wgpu callback associated with a window, if any.
Fields
device: &'a Devicequeue: &'a Queuetarget: &'a TextureViewtarget_format: TextureFormatencoder: &'a mut CommandEncoderAuto Trait Implementations
impl<'a> !RefUnwindSafe for WgpuCtx<'a>
impl<'a> !UnwindSafe for WgpuCtx<'a>
impl<'a> Freeze for WgpuCtx<'a>
impl<'a> Send for WgpuCtx<'a>
impl<'a> Sync for WgpuCtx<'a>
impl<'a> Unpin for WgpuCtx<'a>
impl<'a> UnsafeUnpin for WgpuCtx<'a>